import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@kubernetes-models/base";
/**
 * Output is the schema for namespace level output API
 */
export interface IOutput {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": "fluentbit.fluent.io/v1alpha2";
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": "Output";
    "metadata"?: IObjectMeta;
    /**
     * OutputSpec defines the desired state of ClusterOutput
     */
    "spec"?: {
        /**
         * A user friendly alias name for this output plugin. Used in metrics for distinction of each configured output.
         */
        "alias"?: string;
        /**
         * AzureBlob defines AzureBlob Output Configuration
         */
        "azureBlob"?: {
            /**
             * Azure Storage account name
             */
            "accountName": string;
            /**
             * Creates container if ContainerName is not set.
             */
            "autoCreateContainer"?: boolean;
            /**
             * Specify the desired blob type. Must be `appendblob` or `blockblob`
             */
            "blobType"?: string;
            /**
             * Name of the container that will contain the blobs
             */
            "containerName": string;
            /**
             * Optional toggle to use an Azure emulator
             */
            "emulatorMode"?: boolean;
            /**
             * HTTP Service of the endpoint (if using EmulatorMode)
             */
            "endpoint"?: string;
            /**
             * Optional path to store the blobs.
             */
            "path"?: string;
            /**
             * Specify the Azure Storage Shared Key to authenticate against the storage account
             */
            "sharedKey": {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Enable/Disable TLS Encryption. Azure services require TLS to be enabled.
             */
            "tls"?: boolean;
        };
        /**
         * AzureLogAnalytics defines AzureLogAnalytics Output Configuration
         */
        "azureLogAnalytics"?: {
            /**
             * Customer ID or Workspace ID
             */
            "customerID": {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Name of the event type.
             */
            "logType"?: string;
            /**
             * Specify the primary or the secondary client authentication key
             */
            "sharedKey": {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * If set, overrides the timeKey value with the `time-generated-field` HTTP header value.
             */
            "timeGenerated"?: boolean;
            /**
             * Specify the name of the key where the timestamp is stored.
             */
            "timeKey"?: string;
        };
        /**
         * CloudWatch defines CloudWatch Output Configuration
         */
        "cloudWatch"?: {
            /**
             * Automatically create the log group. Defaults to False.
             */
            "autoCreateGroup"?: boolean;
            /**
             * Automatically retry failed requests to CloudWatch once. Defaults to True.
             */
            "autoRetryRequests"?: boolean;
            /**
             * Custom endpoint for CloudWatch logs API
             */
            "endpoint"?: string;
            /**
             * Specify an external ID for the STS API.
             */
            "externalID"?: string;
            /**
             * Optional parameter to tell CloudWatch the format of the data
             */
            "logFormat"?: string;
            /**
             * Name of Cloudwatch Log Group to send log records to
             */
            "logGroupName"?: string;
            /**
             * Template for Log Group name, overrides LogGroupName if set.
             */
            "logGroupTemplate"?: string;
            /**
             * If set, only the value of the key will be sent to CloudWatch
             */
            "logKey"?: string;
            /**
             * Number of days logs are retained for
             */
            "logRetentionDays"?: 1 | 3 | 5 | 7 | 14 | 30 | 60 | 90 | 120 | 150 | 180 | 365 | 400 | 545 | 731 | 1827 | 3653;
            /**
             * The name of the CloudWatch Log Stream to send log records to
             */
            "logStreamName"?: string;
            /**
             * Prefix for the Log Stream name. Not compatible with LogStreamName setting
             */
            "logStreamPrefix"?: string;
            /**
             * Template for Log Stream name. Overrides LogStreamPrefix and LogStreamName if set.
             */
            "logStreamTemplate"?: string;
            /**
             * Optional lists of lists for dimension keys to be added to all metrics. Use comma separated strings for one list of dimensions and semicolon separated strings for list of lists dimensions.
             */
            "metricDimensions"?: string;
            /**
             * Optional string to represent the CloudWatch namespace.
             */
            "metricNamespace"?: string;
            /**
             * AWS Region
             */
            "region": string;
            /**
             * Role ARN to use for cross-account access
             */
            "roleArn"?: string;
            /**
             * Specify a custom STS endpoint for the AWS STS API
             */
            "stsEndpoint"?: string;
        };
        /**
         * CustomPlugin defines Custom Output configuration.
         */
        "customPlugin"?: {
            "config"?: string;
        };
        /**
         * DataDog defines DataDog Output configuration.
         */
        "datadog"?: {
            /**
             * Your Datadog API key.
             */
            "apikey"?: string;
            /**
             * Compress  the payload in GZIP format. Datadog supports and recommends setting this to gzip.
             */
            "compress"?: string;
            /**
             * By default, the plugin searches for the key 'log' and remap the value to the key 'message'. If the property is set, the plugin will search the property name key.
             */
            "dd_message_key"?: string;
            /**
             * The human readable name for your service generating the logs.
             */
            "dd_service"?: string;
            /**
             * A human readable name for the underlying technology of your service.
             */
            "dd_source"?: string;
            /**
             * The tags you want to assign to your logs in Datadog.
             */
            "dd_tags"?: string;
            /**
             * Host is the Datadog server where you are sending your logs.
             */
            "host"?: string;
            /**
             * If enabled, a tag is appended to output. The key name is used tag_key property.
             */
            "include_tag_key"?: boolean;
            /**
             * Date key name for output.
             */
            "json_date_key"?: string;
            /**
             * To activate the remapping, specify configuration flag provider.
             */
            "provider"?: string;
            /**
             * Specify an HTTP Proxy.
             */
            "proxy"?: string;
            /**
             * The key name of tag. If include_tag_key is false, This property is ignored.
             */
            "tag_key"?: string;
            /**
             * TLS controls whether to use end-to-end security communications security protocol. Datadog recommends setting this to on.
             */
            "tls"?: boolean;
        };
        /**
         * Elasticsearch defines Elasticsearch Output configuration.
         */
        "es"?: {
            /**
             * Enable AWS Sigv4 Authentication for Amazon ElasticSearch Service.
             */
            "awsAuth"?: string;
            /**
             * External ID for the AWS IAM Role specified with aws_role_arn.
             */
            "awsExternalID"?: string;
            /**
             * Specify the AWS region for Amazon ElasticSearch Service.
             */
            "awsRegion"?: string;
            /**
             * AWS IAM Role to assume to put records to your Amazon ES cluster.
             */
            "awsRoleARN"?: string;
            /**
             * Specify the custom sts endpoint to be used with STS API for Amazon ElasticSearch Service.
             */
            "awsSTSEndpoint"?: string;
            /**
             * Specify the buffer size used to read the response from the Elasticsearch HTTP service. This option is useful for debugging purposes where is required to read full responses, note that response size grows depending of the number of records inserted. To set an unlimited amount of memory set this value to False, otherwise the value must be according to the Unit Size specification.
             */
            "bufferSize"?: string;
            /**
             * Specify the credentials to use to connect to Elastic's Elasticsearch Service running on Elastic Cloud.
             */
            "cloudAuth"?: string;
            /**
             * If you are using Elastic's Elasticsearch Service you can specify the cloud_id of the cluster running.
             */
            "cloudID"?: string;
            /**
             * Use current time for index generation instead of message record
             */
            "currentTimeIndex"?: boolean;
            /**
             * When enabled, generate _id for outgoing records. This prevents duplicate records when retrying ES.
             */
            "generateID"?: boolean;
            /**
             * IP address or hostname of the target Elasticsearch instance
             */
            "host"?: string;
            /**
             * Password for user defined in HTTP_User
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional username credential for Elastic X-Pack access
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * If set, _id will be the value of the key from incoming record and Generate_ID option is ignored.
             */
            "idKey"?: string;
            /**
             * When enabled, it append the Tag name to the record.
             */
            "includeTagKey"?: boolean;
            /**
             * Index name
             */
            "index"?: string;
            /**
             * Time format (based on strftime) to generate the second part of the Index name.
             */
            "logstashDateFormat"?: string;
            /**
             * Enable Logstash format compatibility. This option takes a boolean value: True/False, On/Off
             */
            "logstashFormat"?: boolean;
            /**
             * When Logstash_Format is enabled, the Index name is composed using a prefix and the date, e.g: If Logstash_Prefix is equals to 'mydata' your index will become 'mydata-YYYY.MM.DD'. The last string appended belongs to the date when the data is being generated.
             */
            "logstashPrefix"?: string;
            /**
             * Prefix keys with this string
             */
            "logstashPrefixKey"?: string;
            /**
             * Elasticsearch accepts new data on HTTP query path "/_bulk". But it is also possible to serve Elasticsearch behind a reverse proxy on a subpath. This option defines such path on the fluent-bit side. It simply adds a path prefix in the indexing HTTP POST URI.
             */
            "path"?: string;
            /**
             * Newer versions of Elasticsearch allows setting up filters called pipelines. This option allows defining which pipeline the database should use. For performance reasons is strongly suggested parsing and filtering on Fluent Bit side, avoid pipelines.
             */
            "pipeline"?: string;
            /**
             * TCP port of the target Elasticsearch instance
             */
            "port"?: number;
            /**
             * When enabled, replace field name dots with underscore, required by Elasticsearch 2.0-2.3.
             */
            "replaceDots"?: boolean;
            /**
             * When enabled, mapping types is removed and Type option is ignored. Types are deprecated in APIs in v7.0. This options is for v7.0 or later.
             */
            "suppressTypeName"?: string;
            /**
             * When Include_Tag_Key is enabled, this property defines the key name for the tag.
             */
            "tagKey"?: string;
            /**
             * When Logstash_Format is enabled, each record will get a new timestamp field. The Time_Key property defines the name of that field.
             */
            "timeKey"?: string;
            /**
             * When Logstash_Format is enabled, this property defines the format of the timestamp.
             */
            "timeKeyFormat"?: string;
            /**
             * When Logstash_Format is enabled, enabling this property sends nanosecond precision timestamps.
             */
            "timeKeyNanos"?: boolean;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * When enabled print the elasticsearch API calls to stdout when elasticsearch returns an error
             */
            "traceError"?: boolean;
            /**
             * When enabled print the elasticsearch API calls to stdout (for diag only)
             */
            "traceOutput"?: boolean;
            /**
             * Type name
             */
            "type"?: string;
        };
        /**
         * File defines File Output configuration.
         */
        "file"?: {
            /**
             * The character to separate each pair. Applicable only if format is csv or ltsv.
             */
            "delimiter"?: string;
            /**
             * Set file name to store the records. If not set, the file name will be the tag associated with the records.
             */
            "file"?: string;
            /**
             * The format of the file content. See also Format section. Default: out_file.
             */
            "format"?: "out_file" | "plain" | "csv" | "ltsv" | "template";
            /**
             * The character to separate each pair. Applicable only if format is ltsv.
             */
            "labelDelimiter"?: string;
            /**
             * Absolute directory path to store files. If not set, Fluent Bit will write the files on it's own positioned directory.
             */
            "path"?: string;
            /**
             * The format string. Applicable only if format is template.
             */
            "template"?: string;
        };
        /**
         * Firehose defines Firehose Output configuration.
         */
        "firehose"?: {
            /**
             * Immediately retry failed requests to AWS services once. This option does not affect the normal Fluent Bit retry mechanism with backoff. Instead, it enables an immediate retry with no delay for networking errors, which may help improve throughput when there are transient/random networking issues.
             */
            "autoRetryRequests"?: boolean;
            /**
             * By default, the whole log record will be sent to Kinesis. If you specify a key name(s) with this option, then only those keys and values will be sent to Kinesis. For example, if you are using the Fluentd Docker log driver, you can specify data_keys log and only the log message will be sent to Kinesis. If you specify multiple keys, they should be comma delimited.
             */
            "dataKeys"?: string;
            /**
             * The name of the Kinesis Firehose Delivery stream that you want log records sent to.
             */
            "deliveryStream": string;
            /**
             * Specify a custom endpoint for the Kinesis Firehose API.
             */
            "endpoint"?: string;
            /**
             * By default, the whole log record will be sent to Firehose. If you specify a key name with this option, then only the value of that key will be sent to Firehose. For example, if you are using the Fluentd Docker log driver, you can specify log_key log and only the log message will be sent to Firehose.
             */
            "logKey"?: string;
            /**
             * The AWS region.
             */
            "region": string;
            /**
             * ARN of an IAM role to assume (for cross account access).
             */
            "roleARN"?: string;
            /**
             * Specify a custom endpoint for the STS API; used to assume your custom role provided with role_arn.
             */
            "stsEndpoint"?: string;
            /**
             * Add the timestamp to the record under this key. By default, the timestamp from Fluent Bit will not be added to records sent to Kinesis.
             */
            "timeKey"?: string;
            /**
             * strftime compliant format string for the timestamp; for example, %Y-%m-%dT%H \*string This option is used with time_key. You can also use %L for milliseconds and %f for microseconds. If you are using ECS FireLens, make sure you are running Amazon ECS Container Agent v1.42.0 or later, otherwise the timestamps associated with your container logs will only have second precision.
             */
            "timeKeyFormat"?: string;
        };
        /**
         * Forward defines Forward Output configuration.
         */
        "forward"?: {
            /**
             * Use this option to connect to Fluentd with a zero-length secret.
             */
            "emptySharedKey"?: boolean;
            /**
             * Target host where Fluent-Bit or Fluentd are listening for Forward messages.
             */
            "host"?: string;
            /**
             * Specify the password corresponding to the username.
             */
            "password"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * TCP Port of the target service.
             */
            "port"?: number;
            /**
             * Send "chunk"-option and wait for "ack" response from server. Enables at-least-once and receiving server can control rate of traffic. (Requires Fluentd v0.14.0+ server)
             */
            "requireAckResponse"?: boolean;
            /**
             * Default value of the auto-generated certificate common name (CN).
             */
            "selfHostname"?: string;
            /**
             * Always send options (with "size"=count of messages)
             */
            "sendOptions"?: boolean;
            /**
             * A key string known by the remote Fluentd used for authorization.
             */
            "sharedKey"?: string;
            /**
             * Set timestamps in integer format, it enable compatibility mode for Fluentd v0.12 series.
             */
            "timeAsInteger"?: boolean;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * Specify the username to present to a Fluentd server that enables user_auth.
             */
            "username"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
        };
        /**
         * HTTP defines HTTP Output configuration.
         */
        "http"?: {
            /**
             * Specify if duplicated headers are allowed. If a duplicated header is found, the latest key/value set is preserved.
             */
            "allowDuplicatedHeaders"?: boolean;
            /**
             * Set payload compression mechanism. Option available is 'gzip'
             */
            "compress"?: string;
            /**
             * Specify the data format to be used in the HTTP request body, by default it uses msgpack. Other supported formats are json, json_stream and json_lines and gelf.
             */
            "format"?: "msgpack" | "json" | "json_stream" | "json_lines" | "gelf";
            /**
             * Specify the key to use for the full message in gelf format
             */
            "gelfFullMessageKey"?: string;
            /**
             * Specify the key to use for the host in gelf format
             */
            "gelfHostKey"?: string;
            /**
             * Specify the key to use for the level in gelf format
             */
            "gelfLevelKey"?: string;
            /**
             * Specify the key to use as the short message in gelf format
             */
            "gelfShortMessageKey"?: string;
            /**
             * Specify the key to use for timestamp in gelf format
             */
            "gelfTimestampKey"?: string;
            /**
             * Specify an optional HTTP header field for the original message tag.
             */
            "headerTag"?: string;
            /**
             * Add a HTTP header key/value pair. Multiple headers can be set.
             */
            "headers"?: {
                [key: string]: string;
            };
            /**
             * IP address or hostname of the target HTTP Server
             */
            "host"?: string;
            /**
             * Basic Auth Password. Requires HTTP_User to be set
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Basic Auth Username
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Specify the format of the date. Supported formats are double, epoch and iso8601 (eg: 2018-05-30T09:39:52.000681Z)
             */
            "jsonDateFormat"?: string;
            /**
             * Specify the name of the time key in the output record. To disable the time key just set the value to false.
             */
            "jsonDateKey"?: string;
            /**
             * TCP port of the target HTTP Server
             */
            "port"?: number;
            /**
             * Specify an HTTP Proxy. The expected format of this value is http://host:port. Note that https is not supported yet.
             */
            "proxy"?: string;
            /**
             * HTTP output plugin supports TTL/SSL, for more details about the properties available and general configuration, please refer to the TLS/SSL section.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * Specify an optional HTTP URI for the target web server, e.g: /something
             */
            "uri"?: string;
        };
        /**
         * InfluxDB defines InfluxDB Output configuration.
         */
        "influxDB"?: {
            /**
             * Automatically tag keys where value is string.
             */
            "autoTags"?: boolean;
            /**
             * InfluxDB bucket name where records will be inserted - if specified, database is ignored and v2 of API is used
             */
            "bucket"?: string;
            /**
             * InfluxDB database name where records will be inserted.
             */
            "database"?: string;
            /**
             * IP address or hostname of the target InfluxDB service.
             */
            "host": string;
            /**
             * Password for user defined in HTTP_User
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Authentication token used with InfluxDB v2 - if specified, both HTTPUser and HTTPPasswd are ignored
             */
            "httpToken"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional username for HTTP Basic Authentication
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * InfluxDB organization name where the bucket is (v2 only)
             */
            "org"?: string;
            /**
             * TCP port of the target InfluxDB service.
             */
            "port"?: number;
            /**
             * The name of the tag whose value is incremented for the consecutive simultaneous events.
             */
            "sequenceTag"?: string;
            /**
             * List of keys that needs to be tagged
             */
            "tagKeys"?: Array<string>;
            /**
             * Key of the string array optionally contained within each log record that contains tag keys for that record
             */
            "tagListKey"?: string;
            /**
             * Dynamically tag keys which are in the string array at Tags_List_Key key.
             */
            "tagsListEnabled"?: boolean;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
        };
        /**
         * Kafka defines Kafka Output configuration.
         */
        "kafka"?: {
            /**
             * Single of multiple list of Kafka Brokers, e.g: 192.168.1.3:9092, 192.168.1.4:9092.
             */
            "brokers"?: string;
            /**
             * adds unknown topics (found in Topic_Key) to Topics. So in Topics only a default topic needs to be configured
             */
            "dynamicTopic"?: boolean;
            /**
             * Specify data format, options available: json, msgpack.
             */
            "format"?: string;
            /**
             * Optional key to store the message
             */
            "messageKey"?: string;
            /**
             * If set, the value of Message_Key_Field in the record will indicate the message key. If not set nor found in the record, Message_Key will be used (if set).
             */
            "messageKeyField"?: string;
            /**
             * Fluent Bit queues data into rdkafka library, if for some reason the underlying library cannot flush the records the queue might fills up blocking new addition of records. The queue_full_retries option set the number of local retries to enqueue the data. The default value is 10 times, the interval between each retry is 1 second. Setting the queue_full_retries value to 0 set's an unlimited number of retries.
             */
            "queueFullRetries"?: number;
            /**
             * {property} can be any librdkafka properties
             */
            "rdkafka"?: {
                [key: string]: string;
            };
            /**
             * iso8601 or double
             */
            "timestampFormat"?: string;
            /**
             * Set the key to store the record timestamp
             */
            "timestampKey"?: string;
            /**
             * If multiple Topics exists, the value of Topic_Key in the record will indicate the topic to use. E.g: if Topic_Key is router and the record is {"key1": 123, "router": "route_2"}, Fluent Bit will use topic route_2. Note that if the value of Topic_Key is not present in Topics, then by default the first topic in the Topics list will indicate the topic to be used.
             */
            "topicKey"?: string;
            /**
             * Single entry or list of topics separated by comma (,) that Fluent Bit will use to send messages to Kafka. If only one topic is set, that one will be used for all records. Instead if multiple topics exists, the one set in the record by Topic_Key will be used.
             */
            "topics"?: string;
        };
        /**
         * Kinesis defines Kinesis Output configuration.
         */
        "kinesis"?: {
            /**
             * Immediately retry failed requests to AWS services once. This option does not affect the normal Fluent Bit retry mechanism with backoff. Instead, it enables an immediate retry with no delay for networking errors, which may help improve throughput when there are transient/random networking issues. This option defaults to true.
             */
            "autoRetryRequests"?: boolean;
            /**
             * Specify a custom endpoint for the Kinesis API.
             */
            "endpoint"?: string;
            /**
             * Specify an external ID for the STS API, can be used with the role_arn parameter if your role requires an external ID.
             */
            "externalID"?: string;
            /**
             * By default, the whole log record will be sent to Kinesis. If you specify a key name with this option, then only the value of that key will be sent to Kinesis. For example, if you are using the Fluentd Docker log driver, you can specify log_key log and only the log message will be sent to Kinesis.
             */
            "logKey"?: string;
            /**
             * The AWS region.
             */
            "region": string;
            /**
             * ARN of an IAM role to assume (for cross account access).
             */
            "roleARN"?: string;
            /**
             * The name of the Kinesis Streams Delivery stream that you want log records sent to.
             */
            "stream": string;
            /**
             * Custom endpoint for the STS API.
             */
            "stsEndpoint"?: string;
            /**
             * Add the timestamp to the record under this key. By default the timestamp from Fluent Bit will not be added to records sent to Kinesis.
             */
            "timeKey"?: string;
            /**
             * strftime compliant format string for the timestamp; for example, the default is '%Y-%m-%dT%H:%M:%S'. Supports millisecond precision with '%3N' and supports nanosecond precision with '%9N' and '%L'; for example, adding '%3N' to support millisecond '%Y-%m-%dT%H:%M:%S.%3N'. This option is used with time_key.
             */
            "timeKeyFormat"?: string;
        };
        /**
         * Set the plugin's logging verbosity level. Allowed values are: off, error, warn, info, debug and trace, Defaults to the SERVICE section's Log_Level
         */
        "logLevel"?: "off" | "error" | "warning" | "info" | "debug" | "trace";
        /**
         * Loki defines Loki Output configuration.
         */
        "loki"?: {
            /**
             * If set to true, it will add all Kubernetes labels to the Stream labels.
             */
            "autoKubernetesLabels"?: "on" | "off";
            /**
             * If set to true and after extracting labels only a single key remains, the log line sent to Loki will be the value of that key in line_format.
             */
            "dropSingleKey"?: "on" | "off";
            /**
             * Loki hostname or IP address.
             */
            "host": string;
            /**
             * Password for user defined in HTTP_User Set HTTP basic authentication password
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Set HTTP basic authentication user name.
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional list of record keys that will be placed as stream labels. This configuration property is for records key only.
             */
            "labelKeys"?: Array<string>;
            /**
             * Specify the label map file path. The file defines how to extract labels from each record.
             */
            "labelMapPath"?: string;
            /**
             * Stream labels for API request. It can be multiple comma separated of strings specifying  key=value pairs. In addition to fixed parameters, it also allows to add custom record keys (similar to label_keys property).
             */
            "labels"?: Array<string>;
            /**
             * Format to use when flattening the record to a log line. Valid values are json or key_value. If set to json,  the log line sent to Loki will be the Fluent Bit record dumped as JSON. If set to key_value, the log line will be each item in the record concatenated together (separated by a single space) in the format.
             */
            "lineFormat"?: "json" | "key_value";
            /**
             * Loki TCP port
             */
            "port"?: number;
            /**
             * Optional list of keys to remove.
             */
            "removeKeys"?: Array<string>;
            /**
             * Tenant ID used by default to push logs to Loki. If omitted or empty it assumes Loki is running in single-tenant mode and no X-Scope-OrgID header is sent.
             */
            "tenantID"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Specify the name of the key from the original record that contains the Tenant ID. The value of the key is set as X-Scope-OrgID of HTTP header. It is useful to set Tenant ID dynamically.
             */
            "tenantIDKey"?: string;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
        };
        /**
         * A pattern to match against the tags of incoming records. It's case sensitive and support the star (\*) character as a wildcard.
         */
        "match"?: string;
        /**
         * A regular expression to match against the tags of incoming records. Use this option if you want to use the full regex syntax.
         */
        "matchRegex"?: string;
        /**
         * Null defines Null Output configuration.
         */
        "null"?: {};
        /**
         * OpenSearch defines OpenSearch Output configuration.
         */
        "opensearch"?: {
            /**
             * Enables dedicated thread(s) for this output. Default value is set since version 1.8.13. For previous versions is 0.
             */
            "Workers"?: number;
            /**
             * Enable AWS Sigv4 Authentication for Amazon OpenSearch Service.
             */
            "awsAuth"?: string;
            /**
             * External ID for the AWS IAM Role specified with aws_role_arn.
             */
            "awsExternalID"?: string;
            /**
             * Specify the AWS region for Amazon OpenSearch Service.
             */
            "awsRegion"?: string;
            /**
             * AWS IAM Role to assume to put records to your Amazon cluster.
             */
            "awsRoleARN"?: string;
            /**
             * Specify the custom sts endpoint to be used with STS API for Amazon OpenSearch Service.
             */
            "awsSTSEndpoint"?: string;
            /**
             * Specify the buffer size used to read the response from the OpenSearch HTTP service. This option is useful for debugging purposes where is required to read full responses, note that response size grows depending of the number of records inserted. To set an unlimited amount of memory set this value to False, otherwise the value must be according to the Unit Size specification.
             */
            "bufferSize"?: string;
            /**
             * Use current time for index generation instead of message record
             */
            "currentTimeIndex"?: boolean;
            /**
             * When enabled, generate _id for outgoing records. This prevents duplicate records when retrying OpenSearch.
             */
            "generateID"?: boolean;
            /**
             * IP address or hostname of the target OpenSearch instance, default `127.0.0.1`
             */
            "host"?: string;
            /**
             * Password for user defined in HTTP_User
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional username credential for access
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * If set, _id will be the value of the key from incoming record and Generate_ID option is ignored.
             */
            "idKey"?: string;
            /**
             * When enabled, it append the Tag name to the record.
             */
            "includeTagKey"?: boolean;
            /**
             * Index name
             */
            "index"?: string;
            /**
             * Time format (based on strftime) to generate the second part of the Index name.
             */
            "logstashDateFormat"?: string;
            /**
             * Enable Logstash format compatibility. This option takes a boolean value: True/False, On/Off
             */
            "logstashFormat"?: boolean;
            /**
             * When Logstash_Format is enabled, the Index name is composed using a prefix and the date, e.g: If Logstash_Prefix is equals to 'mydata' your index will become 'mydata-YYYY.MM.DD'. The last string appended belongs to the date when the data is being generated.
             */
            "logstashPrefix"?: string;
            /**
             * Prefix keys with this string
             */
            "logstashPrefixKey"?: string;
            /**
             * OpenSearch accepts new data on HTTP query path "/_bulk". But it is also possible to serve OpenSearch behind a reverse proxy on a subpath. This option defines such path on the fluent-bit side. It simply adds a path prefix in the indexing HTTP POST URI.
             */
            "path"?: string;
            /**
             * OpenSearch allows to setup filters called pipelines. This option allows to define which pipeline the database should use. For performance reasons is strongly suggested to do parsing and filtering on Fluent Bit side, avoid pipelines.
             */
            "pipeline"?: string;
            /**
             * TCP port of the target OpenSearch instance, default `9200`
             */
            "port"?: number;
            /**
             * When enabled, replace field name dots with underscore, required by Elasticsearch 2.0-2.3.
             */
            "replaceDots"?: boolean;
            /**
             * When enabled, mapping types is removed and Type option is ignored. Types are deprecated in APIs in v7.0. This options is for v7.0 or later.
             */
            "suppressTypeName"?: boolean;
            /**
             * When Include_Tag_Key is enabled, this property defines the key name for the tag.
             */
            "tagKey"?: string;
            /**
             * When Logstash_Format is enabled, each record will get a new timestamp field. The Time_Key property defines the name of that field.
             */
            "timeKey"?: string;
            /**
             * When Logstash_Format is enabled, this property defines the format of the timestamp.
             */
            "timeKeyFormat"?: string;
            /**
             * When Logstash_Format is enabled, enabling this property sends nanosecond precision timestamps.
             */
            "timeKeyNanos"?: boolean;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * Limit the maximum number of Chunks in the filesystem for the current output logical destination.
             */
            "totalLimitSize"?: string;
            /**
             * When enabled print the elasticsearch API calls to stdout when elasticsearch returns an error
             */
            "traceError"?: boolean;
            /**
             * When enabled print the elasticsearch API calls to stdout (for diag only)
             */
            "traceOutput"?: boolean;
            /**
             * Type name
             */
            "type"?: string;
            /**
             * Operation to use to write in bulk requests.
             */
            "writeOperation"?: string;
        };
        /**
         * OpenTelemetry defines OpenTelemetry Output configuration.
         */
        "opentelemetry"?: {
            /**
             * This allows you to add custom labels to all metrics exposed through the OpenTelemetry exporter. You may have multiple of these fields.
             */
            "addLabel"?: {
                [key: string]: string;
            };
            /**
             * Add a HTTP header key/value pair. Multiple headers can be set.
             */
            "header"?: {
                [key: string]: string;
            };
            /**
             * IP address or hostname of the target HTTP Server, default `127.0.0.1`
             */
            "host"?: string;
            /**
             * Password for user defined in HTTP_User
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional username credential for access
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Log the response payload within the Fluent Bit log.
             */
            "logResponsePayload"?: boolean;
            /**
             * Specify an optional HTTP URI for the target web server listening for logs, e.g: /v1/logs
             */
            "logsUri"?: string;
            /**
             * Specify an optional HTTP URI for the target web server listening for metrics, e.g: /v1/metrics
             */
            "metricsUri"?: string;
            /**
             * TCP port of the target OpenSearch instance, default `80`
             */
            "port"?: number;
            /**
             * Specify an HTTP Proxy. The expected format of this value is http://HOST:PORT. Note that HTTPS is not currently supported. It is recommended not to set this and to configure the HTTP proxy environment variables instead as they support both HTTP and HTTPS.
             */
            "proxy"?: string;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * Specify an optional HTTP URI for the target web server listening for traces, e.g: /v1/traces
             */
            "tracesUri"?: string;
        };
        /**
         * PrometheusRemoteWrite_types defines Prometheus Remote Write configuration.
         */
        "prometheusRemoteWrite"?: {
            /**
             * This allows you to add custom labels to all metrics exposed through the prometheus exporter. You may have multiple of these fields
             */
            "addLabels"?: {
                [key: string]: string;
            };
            /**
             * Add a HTTP header key/value pair. Multiple headers can be set.
             */
            "headers"?: {
                [key: string]: string;
            };
            /**
             * IP address or hostname of the target HTTP Server, default: 127.0.0.1
             */
            "host": string;
            /**
             * Basic Auth Password. Requires HTTP_user to be se
             */
            "httpPasswd"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Basic Auth Username
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Log the response payload within the Fluent Bit log,default: false
             */
            "logResponsePayload"?: boolean;
            /**
             * TCP port of the target HTTP Serveri, default:80
             */
            "port"?: number;
            /**
             * Specify an HTTP Proxy. The expected format of this value is http://HOST:PORT.
             */
            "proxy"?: string;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
            /**
             * Specify an optional HTTP URI for the target web server, e.g: /something ,default: /
             */
            "uri"?: string;
            /**
             * Enables dedicated thread(s) for this output. Default value is set since version 1.8.13. For previous versions is 0,default : 2
             */
            "workers"?: number;
        };
        /**
         * RetryLimit represents configuration for the scheduler which can be set independently on each output section. This option allows to disable retries or impose a limit to try N times and then discard the data after reaching that limit.
         */
        "retry_limit"?: string;
        /**
         * S3 defines S3 Output configuration.
         */
        "s3"?: {
            /**
             * Immediately retry failed requests to AWS services once.
             */
            "AutoRetryRequests"?: boolean;
            /**
             * S3 Bucket name
             */
            "Bucket": string;
            /**
             * Predefined Canned ACL Policy for S3 objects.
             */
            "CannedAcl"?: string;
            /**
             * Compression type for S3 objects.
             */
            "Compression"?: string;
            /**
             * A standard MIME type for the S3 object; this will be set as the Content-Type HTTP header.
             */
            "ContentType"?: string;
            /**
             * Custom endpoint for the S3 API.
             */
            "Endpoint"?: string;
            /**
             * Specify an external ID for the STS API, can be used with the role_arn parameter if your role requires an external ID.
             */
            "ExternalId"?: string;
            /**
             * Specify the format of the date. Supported formats are double, epoch, iso8601 (eg: 2018-05-30T09:39:52.000681Z) and java_sql_timestamp (eg: 2018-05-30 09:39:52.000681)
             */
            "JsonDateFormat"?: string;
            /**
             * Specify the name of the time key in the output record. To disable the time key just set the value to false.
             */
            "JsonDateKey"?: string;
            /**
             * By default, the whole log record will be sent to S3. If you specify a key name with this option, then only the value of that key will be sent to S3.
             */
            "LogKey"?: string;
            /**
             * Normally, when an upload request fails, there is a high chance for the last received chunk to be swapped with a later chunk, resulting in data shuffling. This feature prevents this shuffling by using a queue logic for uploads.
             */
            "PreserveDataOrdering"?: boolean;
            /**
             * The AWS region of your S3 bucket
             */
            "Region": string;
            /**
             * Integer value to set the maximum number of retries allowed.
             */
            "RetryLimit"?: number;
            /**
             * ARN of an IAM role to assume
             */
            "RoleArn"?: string;
            /**
             * Format string for keys in S3.
             */
            "S3KeyFormat"?: string;
            /**
             * A series of characters which will be used to split the tag into 'parts' for use with the s3_key_format option.
             */
            "S3KeyFormatTagDelimiters"?: string;
            /**
             * Send the Content-MD5 header with PutObject and UploadPart requests, as is required when Object Lock is enabled.
             */
            "SendContentMd5"?: boolean;
            /**
             * Disables behavior where UUID string is automatically appended to end of S3 key name when $UUID is not provided in s3_key_format. $UUID, time formatters, $TAG, and other dynamic key formatters all work as expected while this feature is set to true.
             */
            "StaticFilePath"?: boolean;
            /**
             * Specify the storage class for S3 objects. If this option is not specified, objects will be stored with the default 'STANDARD' storage class.
             */
            "StorageClass"?: string;
            /**
             * Directory to locally buffer data before sending.
             */
            "StoreDir"?: string;
            /**
             * The size of the limitation for disk usage in S3.
             */
            "StoreDirLimitSize"?: string;
            /**
             * Custom endpoint for the STS API.
             */
            "StsEndpoint"?: string;
            /**
             * Specifies the size of files in S3. Minimum size is 1M. With use_put_object On the maximum size is 1G. With multipart upload mode, the maximum size is 50G.
             */
            "TotalFileSize"?: string;
            /**
             * The size of each 'part' for multipart uploads. Max: 50M
             */
            "UploadChunkSize"?: string;
            /**
             * Whenever this amount of time has elapsed, Fluent Bit will complete an upload and create a new file in S3. For example, set this value to 60m and you will get a new file every hour.
             */
            "UploadTimeout"?: string;
            /**
             * Use the S3 PutObject API, instead of the multipart upload API.
             */
            "UsePutObject"?: boolean;
        };
        /**
         * Splunk defines Splunk Output Configuration
         */
        "splunk"?: {
            /**
             * Enables dedicated thread(s) for this output. Default value `2` is set since version 1.8.13. For previous versions is 0.
             */
            "Workers"?: number;
            /**
             * Specify X-Splunk-Request-Channel Header for the HTTP Event Collector interface.
             */
            "channel"?: string;
            /**
             * Set payload compression mechanism. The only available option is gzip.
             */
            "compress"?: string;
            /**
             * Set event fields for the record. This option is an array and the format is "key_name record_accessor_pattern".
             */
            "eventFields"?: Array<string>;
            /**
             * Specify the key name that contains the host value. This option allows a record accessors pattern.
             */
            "eventHost"?: string;
            /**
             * The name of the index by which the event data is to be indexed.
             */
            "eventIndex"?: string;
            /**
             * Set a record key that will populate the index field. If the key is found, it will have precedence over the value set in event_index.
             */
            "eventIndexKey"?: string;
            /**
             * Specify the key name that will be used to send a single value as part of the record.
             */
            "eventKey"?: string;
            /**
             * Set the source value to assign to the event data.
             */
            "eventSource"?: string;
            /**
             * Set the sourcetype value to assign to the event data.
             */
            "eventSourcetype"?: string;
            /**
             * Set a record key that will populate 'sourcetype'. If the key is found, it will have precedence over the value set in event_sourcetype.
             */
            "eventSourcetypeKey"?: string;
            /**
             * IP address or hostname of the target OpenSearch instance, default `127.0.0.1`
             */
            "host"?: string;
            /**
             * Buffer size used to receive Splunk HTTP responses: Default `2M`
             */
            "httpBufferSize"?: string;
            /**
             * If the HTTP server response code is 400 (bad request) and this flag is enabled, it will print the full HTTP request and response to the stdout interface. This feature is available for debugging purposes.
             */
            "httpDebugBadRequest"?: boolean;
            /**
             * Password for user defined in HTTP_User
             */
            "httpPassword"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Optional username credential for access
             */
            "httpUser"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * TCP port of the target Splunk instance, default `8088`
             */
            "port"?: number;
            /**
             * When enabled, the record keys and values are set in the top level of the map instead of under the event key. Refer to the Sending Raw Events section from the docs more details to make this option work properly.
             */
            "splunkSendRaw"?: boolean;
            /**
             * Specify the Authentication Token for the HTTP Event Collector interface.
             */
            "splunkToken"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
        };
        /**
         * Stackdriver defines Stackdriver Output Configuration
         */
        "stackdriver"?: {
            /**
             * Rewrite the trace field to be formatted for use with GCP Cloud Trace
             */
            "autoformatStackdriverTrace"?: boolean;
            /**
             * A custom regex to extract fields from the local_resource_id of the logs
             */
            "customK8sRegex"?: string;
            /**
             * The GCP Project that should receive the logs
             */
            "exportToProjectID"?: string;
            /**
             * Path to GCP Credentials JSON file
             */
            "googleServiceCredentials"?: string;
            /**
             * Identifier for a grouping of tasks. Required if Resource is generic_task
             */
            "job"?: string;
            /**
             * Location of the cluster that contains the pods/nodes. Required if Resource is k8s_container, k8s_node, or k8s_pod
             */
            "k8sClusterLocation"?: string;
            /**
             * Name of the cluster that the pod is running in. Required if Resource is k8s_container, k8s_node, or k8s_pod
             */
            "k8sClusterName"?: string;
            /**
             * Optional list of comma separated of strings for key/value pairs
             */
            "labels"?: Array<string>;
            /**
             * Used by Stackdriver to find related labels and extract them to LogEntry Labels
             */
            "labelsKey"?: string;
            /**
             * GCP/AWS region to store data. Required if Resource is generic_node or generic_task
             */
            "location"?: string;
            /**
             * The value of this field is set as the logName field in Stackdriver
             */
            "logNameKey"?: string;
            /**
             * Metadata Server Prefix
             */
            "metadataServer"?: string;
            /**
             * Namespace identifier. Required if Resource is generic_node or generic_task
             */
            "namespace"?: string;
            /**
             * Node identifier within the namespace. Required if Resource is generic_node or generic_task
             */
            "nodeID"?: string;
            /**
             * Set resource types of data
             */
            "resource"?: string;
            /**
             * Optional list of comma seperated strings. Setting these fields overrides the Stackdriver monitored resource API values
             */
            "resourceLabels"?: Array<string>;
            /**
             * Email associated with the service
             */
            "serviceAccountEmail"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Private Key associated with the service
             */
            "serviceAccountSecret"?: {
                /**
                 * ValueSource defines how to find a value's key.
                 */
                "valueFrom"?: {
                    /**
                     * Selects a key of a secret in the pod's namespace
                     */
                    "secretKeyRef"?: {
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        "key": string;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                         */
                        "name"?: string;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        "optional"?: boolean;
                    };
                };
            };
            /**
             * Specify the key that contains the severity information for the logs
             */
            "severityKey"?: string;
            /**
             * Used to validate the tags of logs that when the Resource is k8s_container, k8s_node, or k8s_pod
             */
            "tagPrefix"?: string;
            /**
             * Identifier for a task within a namespace. Required if Resource is generic_task
             */
            "taskID"?: string;
            /**
             * Number of dedicated threads for the Stackdriver Output Plugin
             */
            "workers"?: number;
        };
        /**
         * Stdout defines Stdout Output configuration.
         */
        "stdout"?: {
            /**
             * Specify the data format to be printed. Supported formats are msgpack json, json_lines and json_stream.
             */
            "format"?: "msgpack" | "json" | "json_lines" | "json_stream";
            /**
             * Specify the format of the date. Supported formats are double,  iso8601 (eg: 2018-05-30T09:39:52.000681Z) and epoch.
             */
            "jsonDateFormat"?: "double" | "iso8601" | "epoch";
            /**
             * Specify the name of the date field in output.
             */
            "jsonDateKey"?: string;
        };
        /**
         * Syslog defines Syslog Output configuration.
         */
        "syslog"?: {
            /**
             * Host domain or IP address of the remote Syslog server.
             */
            "host"?: string;
            /**
             * Mode of the desired transport type, the available options are tcp, tls and udp.
             */
            "mode"?: string;
            /**
             * TCP or UDP port of the remote Syslog server.
             */
            "port"?: number;
            /**
             * Key name from the original record that contains the application name that generated the message.
             */
            "syslogAppnameKey"?: string;
            /**
             * Key from the original record that contains the Syslog facility number.
             */
            "syslogFacilityKey"?: string;
            /**
             * Syslog protocol format to use, the available options are rfc3164 and rfc5424.
             */
            "syslogFormat"?: string;
            /**
             * Key name from the original record that contains the hostname that generated the message.
             */
            "syslogHostnameKey"?: string;
            /**
             * Maximum size allowed per message, in bytes.
             */
            "syslogMaxSize"?: number;
            /**
             * Key name from the original record that contains the Message ID associated to the message.
             */
            "syslogMessageIDKey"?: string;
            /**
             * Key key name that contains the message to deliver.
             */
            "syslogMessageKey"?: string;
            /**
             * Key name from the original record that contains the Process ID that generated the message.
             */
            "syslogProcessIDKey"?: string;
            /**
             * Key name from the original record that contains the Structured Data (SD) content.
             */
            "syslogSDKey"?: string;
            /**
             * Key from the original record that contains the Syslog severity number.
             */
            "syslogSeverityKey"?: string;
            /**
             * Syslog output plugin supports TTL/SSL, for more details about the properties available and general configuration, please refer to the TLS/SSL section.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
        };
        /**
         * TCP defines TCP Output configuration.
         */
        "tcp"?: {
            /**
             * Specify the data format to be printed. Supported formats are msgpack json, json_lines and json_stream.
             */
            "format"?: "msgpack" | "json" | "json_lines" | "json_stream";
            /**
             * Target host where Fluent-Bit or Fluentd are listening for Forward messages.
             */
            "host"?: string;
            /**
             * Specify the format of the date. Supported formats are double, epoch and iso8601 (eg: 2018-05-30T09:39:52.000681Z)
             */
            "jsonDateFormat"?: "double" | "epoch" | "iso8601";
            /**
             * TSpecify the name of the time key in the output record. To disable the time key just set the value to false.
             */
            "jsonDateKey"?: string;
            /**
             * TCP Port of the target service.
             */
            "port"?: number;
            /**
             * Fluent Bit provides integrated support for Transport Layer Security (TLS) and it predecessor Secure Sockets Layer (SSL) respectively.
             */
            "tls"?: {
                /**
                 * Absolute path to CA certificate file
                 */
                "caFile"?: string;
                /**
                 * Absolute path to scan for certificate files
                 */
                "caPath"?: string;
                /**
                 * Absolute path to Certificate file
                 */
                "crtFile"?: string;
                /**
                 * Set TLS debug verbosity level. It accept the following values: 0 (No debug), 1 (Error), 2 (State change), 3 (Informational) and 4 Verbose
                 */
                "debug"?: 0 | 1 | 2 | 3 | 4;
                /**
                 * Absolute path to private Key file
                 */
                "keyFile"?: string;
                /**
                 * Optional password for tls.key_file file
                 */
                "keyPassword"?: {
                    /**
                     * ValueSource defines how to find a value's key.
                     */
                    "valueFrom"?: {
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        "secretKeyRef"?: {
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            "key": string;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                             */
                            "name"?: string;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            "optional"?: boolean;
                        };
                    };
                };
                /**
                 * Force certificate validation
                 */
                "verify"?: boolean;
                /**
                 * Hostname to be used for TLS SNI extension
                 */
                "vhost"?: string;
            };
        };
    };
}
/**
 * Output is the schema for namespace level output API
 */
export declare class Output extends Model<IOutput> implements IOutput {
    "apiVersion": IOutput["apiVersion"];
    "kind": IOutput["kind"];
    "metadata"?: IOutput["metadata"];
    "spec"?: IOutput["spec"];
    static apiVersion: IOutput["apiVersion"];
    static kind: IOutput["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IOutput>;
    constructor(data?: ModelData<IOutput>);
}
